@@ -19,7 +19,6 @@ def download_v1(url, saveToArchive=False, setDateToToday=False):
         return result
     return False
 
-@Validator.mongo_save
 def download(url):
     return download_v2(url)
 
@@ -30,9 +29,9 @@ def download_v2(url):
     if downloader_v1 and Validator.validate_article(downloader_v1):
         return downloader_v1
     # -> v2
-    downloader_v2 = fweb_downloader_v2(url)
-    if downloader_v2 and Validator.validate_article(downloader_v2):
-        return downloader_v2.json
+    # downloader_v2 = fweb_downloader_v2(url)
+    # if downloader_v2 and Validator.validate_article(downloader_v2):
+    #     return downloader_v2.json
     return False
 
 @Validator.mongo_save
@@ -85,4 +84,8 @@ def fweb_response(url, response, client="fweb_response"):
 if __name__ == '__main__':
     url1 = "https://www.americanbanker.com/payments/news/inside-ripples-plans-for-mainstream-crypto-payments",
     url2 = "https://towardsdatascience.com/decorators-in-python-fundamentals-for-data-scientists-eada7f4eba85"
-    download(url2)
\ No newline at end of file
+    url3 = "https://www.wsj.com/articles/meta-platforms-facebook-fb-q1-earnings-report-2022-1165102219"
+    url4 = "https://www.newsobserver.com/news/business/article260136540.html"
+    wallstreetj = "https://www.wsj.com/articles/primary-elections-2022-south-carolina-nevada-races-test-trumps-sway-in-gop-11655199002"
+    date_none = "https://finance.yahoo.com/news/metaverse-real-estate-market-growing-115600231.html"
+    download(date_none)
\ No newline at end of file
